@@ -33,23 +33,21 @@ class VisionClassifierTrainer:
   """
   def __init__(
     self,
-    model:torch.nn.Module,
-    feature_extractor:FeatureExtractionMixin,
     ids2labels,
-    model_name:str,
-    dataset:torch.utils.data.Dataset,
-    output_dir:str,
-    lr=2e-5,
-    batch_size=8,
-    max_epochs=1,
-    shuffle=True,
-    test_ratio=0.15,
-    dev_ratio=0.15,
-    cores=4,
-    fp16=True,
-    eval_metric="accuracy",
-    balanced=False,
-    augmentation=False,
+    model             :torch.nn.Module,
+    feature_extractor :FeatureExtractionMixin,
+    dataset           :torch.utils.data.Dataset,
+    model_name        :str,
+    output_dir        :str,
+    lr           = 2e-5,
+    batch_size   = 8,
+    max_epochs   = 1,
+    cores        = 4,
+    eval_metric  = "accuracy",
+    shuffle      = True,
+    fp16         = True,
+    balanced     = False,
+    augmentation = False,
   ):
 
     self.model_name        = model_name
@@ -59,8 +57,6 @@ class VisionClassifierTrainer:
     self.batch_size        = batch_size
     self.max_epochs        = max_epochs
     self.shuffle           = shuffle
-    self.test_ratio        = test_ratio
-    self.dev_ratio         = dev_ratio
     self.model             = model
     self.feature_extractor = feature_extractor
     self.cores             = cores
@@ -86,34 +82,31 @@ class VisionClassifierTrainer:
     # Open the logs file
     self.__openLogs()
 
-    # Split and convert to dataloaders
-    self.train, self.dev, self.test = self.__splitDatasets()
-
     """
     🏗️ Build the trainer
     """
     self.training_args = TrainingArguments(
-        output_dir=self.output_path,
-        evaluation_strategy="epoch",
-        learning_rate=self.lr,
-        per_device_train_batch_size=self.batch_size,
-        per_device_eval_batch_size=self.batch_size,
-        num_train_epochs=self.max_epochs,
-        save_steps=10000,
-        save_total_limit=2,
-        weight_decay=0.01,
-        load_best_model_at_end=False,
-        metric_for_best_model=self.eval_metric,
-        logging_dir=self.logs_path,
-        overwrite_output_dir=True,
-        fp16=self.fp16,
+        output_dir                  = self.output_path,
+        save_steps                  = 10000,
+        save_total_limit            = 2,
+        weight_decay                = 0.01,
+        learning_rate               = self.lr,
+        per_device_train_batch_size = self.batch_size,
+        per_device_eval_batch_size  = self.batch_size,
+        num_train_epochs            = self.max_epochs,
+        metric_for_best_model       = self.eval_metric,
+        logging_dir                 = self.logs_path,
+        fp16                        = self.fp16,
+        evaluation_strategy         = "epoch",
+        overwrite_output_dir        = True,
+        load_best_model_at_end      = False,
     )
     
     self.trainer = Trainer(
       self.model,
       self.training_args,
-      train_dataset = self.train,
-      eval_dataset = self.dev,
+      train_dataset = self.dataset["train"],
+      eval_dataset  = self.dataset["test"],
       data_collator = self.collator,
     )
     print("Trainer builded!")
@@ -156,138 +149,28 @@ class VisionClassifierTrainer:
     return path
 
   """
-  🧬 Apply data augmentation on the input image
-  Source: https://medium.com/lunit/photometric-data-augmentation-in-projection-radiography-bed3ae9f55c3
+  🧪 Evaluate the performances of the system of the test sub-dataset
   """
-  def __augmentation(self, image):
-
-    # im3 = ImageEnhance.Contrast(image)
-    # im3.enhance(0.05).save("/users/ylabrak/Visual Transformers - ViT2/data/test05.png")
-    # im3.enhance(0.25).save("/users/ylabrak/Visual Transformers - ViT2/data/test25.png")
-    # im3.enhance(0.50).save("/users/ylabrak/Visual Transformers - ViT2/data/test50.png")
-    # im3.enhance(1.00).save("/users/ylabrak/Visual Transformers - ViT2/data/test100.png")
-    # exit(0)
-
-    # Random augmentation
-    if random.randint(0,100) < 33:
-    
-      im3 = ImageEnhance.Contrast(image)
-      im3.enhance(random.uniform(0.5, 1.0)).show()
-      
-      # # Random Contrast
-      # if random.randint(0,100) < 36:
-      #   im3 = ImageEnhance.Contrast(image)
-      #   im3.enhance(random.uniform(0.5, 1.0)).show()
-
-      # # Random Noise
-      # if bool(random.getrandbits(1)) == True:
-      #   im3 = ImageEnhance.Contrast(image)
-      #   im3.enhance(random.uniform(0.5, 1.0)).show()
-
-    return image
-    
-  """
-  ✂️ Split the dataset into sub-datasets
-  """
-  def __splitDatasets(self):
-
-    print("Split Datasets...")
-    
-    indices = torch.randperm(len(self.dataset)).tolist()
-
-    # Index of the validation corpora
-    elements_test_dev = math.floor(len(indices) * .15)
-
-    # TRAIN
-    train_ds = torch.utils.data.Subset(self.dataset, indices[:-elements_test_dev*2])
-    ct_train = Counter([label for _, label in train_ds])
-    train_classes = [ct_train[a] for a in sorted(ct_train)]
-    
-    # If balanced is enabled
-    if self.balanced == True:
-
-      # Get the less represented label in train
-      less_represented_train = min(train_classes)
-
-      labels = {}
-
-      # For each image
-      for img, label in train_ds:
-
-        # Create the label array if isn't
-        if label not in labels:
-          labels[label] = []
+  def __evaluate(self):
         
-        # Add the image to the array
-        labels[label].append(img)
-      
-      # New dataset
-      balanced_ds = []
+    all_preds  = []
+    all_target = []
 
-      # For each label
-      for label in labels:
+    # For each image
+    for image, label in tqdm(self.dataset["test"]):
 
-        # Get images
-        imgs = labels[label]
+        # Compute
+        inputs  = self.feature_extractor(images=image, return_tensors="pt").to(self.device)
+        outputs = self.model(**inputs)
 
-        # For each image
-        for img in imgs[0:less_represented_train]:
+        # Get predictions from the softmax layer
+        preds = outputs.logits.softmax(1).argmax(1).tolist()
+        all_preds.extend(preds)
 
-          # Create a tuple: image and label 
-          t = (img, label)
+        # Get hypothesis
+        all_target.append(label)
 
-          # Add it
-          balanced_ds.append(t)
-
-      print("The less represented label in train as " + str(less_represented_train) + " occurrences")
-      print("Size of train after balancing is " + str(len(balanced_ds)))
-
-      # Overwrite
-      train_ds = balanced_ds
-      
-      # Compute again the stats
-      ct_train = Counter([label for _, label in train_ds])
-      train_classes = [ct_train[a] for a in sorted(ct_train)]
-
-    # If data augmentation is enabled
-    if self.augmentation == True:
-
-      new_ds = []
-
-      # For each annotated image
-      for img, label in train_ds:
-
-        # Augment it
-        new_ds.append(
-          (self.__augmentation(img), label)
-        )
-      
-      # Replace by the augmented data
-      train_ds = new_ds
-
-    # DEV
-    val_ds = torch.utils.data.Subset(self.dataset, indices[-elements_test_dev*2:-elements_test_dev])
-    ct_val = Counter([label for _, label in val_ds])
-    val_classes = [ct_val[a] for a in sorted(ct_val)]
-
-    # TEST
-    test_ds = torch.utils.data.Subset(self.dataset, indices[-elements_test_dev:])
-    ct_test = Counter([label for _, label in test_ds])
-    test_classes = [ct_test[a] for a in sorted(ct_test)]
-
-    table_repartition = [
-      ["Train"] + train_classes + [str(len(train_ds))],
-      ["Dev"] + val_classes + [str(len(val_ds))],
-      ["Test"] + test_classes + [str(len(test_ds))],
-    ]
-
-    repartitions_table = tabulate(table_repartition, ["Dataset"] + list(self.ids2labels.values()) + ["Total"], tablefmt="pretty")
-    print(repartitions_table)
-
-    # Write logs
-    self.logs_file.write(repartitions_table + "\n")
-
-    return train_ds, val_ds, test_ds
+    return all_preds, all_target
 
   """
   🧪 Evaluate the performances of the system of the test sub-dataset given a f1-score
@@ -295,7 +178,7 @@ class VisionClassifierTrainer:
   def evaluate_f1_score(self):
 
     # Get the hypothesis and predictions
-    all_target, all_preds = self.evaluate()
+    all_target, all_preds = self.__evaluate()
 
     # Get the labels as a list
     labels = list(self.ids2labels.keys())
@@ -341,30 +224,6 @@ class VisionClassifierTrainer:
 
     return all_target, all_preds
 
-  """
-  🧪 Evaluate the performances of the system of the test sub-dataset
-  """
-  def evaluate(self):
-        
-    all_preds  = []
-    all_target = []
-
-    # For each image
-    for image, label in tqdm(self.test):
-
-        # Compute
-        inputs  = self.feature_extractor(images=image, return_tensors="pt").to(self.device)
-        outputs = self.model(**inputs)
-
-        # Get predictions from the softmax layer
-        preds = outputs.logits.softmax(1).argmax(1).tolist()
-        all_preds.extend(preds)
-
-        # Get hypothesis
-        all_target.append(label)
-
-    return all_preds, all_target
-
   """
   🧪 Test on a single image
   """
